@@ -11,9 +11,8 @@ def holland_B(hurdat, coriolis=True):
     air_density = 1.15
 
     def with_coriolis(Vmax, Rmax, Pn, Pc, eye_lat):
-        f = 2. * 7.2921e-5 * np.sin(np.radians(np.abs(eye_lat)))
-        return (Vmax ** 2 + Vmax * Rmax * f * air_density * np.exp(1)) / (
-                Pn - Pc)
+        f = 2.0 * 7.2921e-5 * np.sin(np.radians(np.abs(eye_lat)))
+        return (Vmax ** 2 + Vmax * Rmax * f * air_density * np.exp(1)) / (Pn - Pc)
 
     def no_coriolis(Vmax, Pn, Pc):
         return (Vmax ** 2 * air_density * np.exp(1)) / (Pn - Pc)
@@ -31,12 +30,10 @@ def holland_B(hurdat, coriolis=True):
                 data['radius_of_maximum_winds'],
                 Pn,
                 Pc,
-                data['eye']['lat'])
+                data['eye']['lat'],
+            )
         else:
-            return no_coriolis(
-                data['max_sustained_wind_speed'],
-                Pn,
-                Pc)
+            return no_coriolis(data['max_sustained_wind_speed'], Pn, Pc)
 
 
 def main():
@@ -55,8 +52,7 @@ def main():
         B = 1.0
 
         def holland2010(r, B, x):
-            return Vmax * (
-                    ((Rmax / r) ** B) * np.exp(1 - (Rmax / r) ** B)) ** x
+            return Vmax * (((Rmax / r) ** B) * np.exp(1 - (Rmax / r) ** B)) ** x
 
         def V(B, x):
             def v(r):
@@ -80,14 +76,14 @@ def main():
             p0 = [B, x]
             # do curve fitting
             with warnings.catch_warnings():
-                warnings.simplefilter("ignore")
+                warnings.simplefilter('ignore')
                 popt, pcov = optimize.curve_fit(
                     holland2010,
                     xdata,
                     ydata,
                     p0=p0,
                     # bounds=bounds,
-                    method='dogbox'
+                    method='dogbox',
                 )
                 print(popt)
             v = V(*popt)
@@ -110,6 +106,7 @@ def init():
     if __name__ == '__main__':
         try:
             import colored_traceback
+
             colored_traceback.add_hook(always=True)
         except ModuleNotFoundError:
             pass
