@@ -18,19 +18,37 @@ import geopandas
 from haversine import haversine
 import matplotlib.pyplot as plt
 from matplotlib.transforms import Bbox
+import numpy
 import numpy as np
 from pandas import DataFrame, read_csv
 import pyproj
 from pyproj import CRS, Proj
 from shapely import ops
 from shapely.geometry import Point, Polygon
-import utm
+
 
 from adcircpy.forcing.winds.base import WindForcing
 
 logger = logging.getLogger(__name__)
 
 
+def _dist(points1, points2) -> np.ndarray:
+    R = 6373.0  # radius of earth
+    lons1, lats1 = np.hsplit(points1, 2)
+    lons2, lats2 = np.hsplit(points2, 2)
+    lats1 = np.radians(lats1)
+    lons1 = np.radians(lons1)
+    lats2 = np.radians(lats2)
+    lons2 = np.radians(lons2)
+
+    dlons = lons2 - lons1
+    dlats = lats2 - lats1
+
+    a = np.sin(dlats / 2) ** 2 + np.cos(lats1) * np.cos(lats2) * np.sin(dlons / 2) ** 2
+    c = 2 * np.arctan2(np.sqrt(a), np.sqrt(1 - a))
+    return R * c
+
+
 def _fetch_and_plot_coastline(_ax, show, filename='BestTrack.png'):
     save_dir = pathlib.Path(appdirs.user_data_dir('ne_coastline'))
     save_dir.mkdir(exist_ok=True, parents=True)
@@ -94,6 +112,34 @@ class BestTrackForcing(WindForcing):
 
         super().__init__(nws=nws, interval_seconds=interval_seconds)
 
+    def summary(self, output: Union[str, os.PathLike] = None, overwrite: bool = False):
+        min_storm_speed = np.min(self.speed)
+        max_storm_speed = np.max(self.speed)
+        track_length = self.track_length
+        duration = self.duration
+        min_central_pressure = np.min(self.central_pressure)
+        max_wind_speed = np.max(self.df['max_sustained_wind_speed'])
+        start_loc = (self.df['longitude'][0], self.df['latitude'][0])
+        end_loc = (self.df['longitude'].iloc[-1], self.df['latitude'].iloc[-1])
+        f = [
+            f'Summary of storm: {self.storm_id}',
+            f'min./max. track speed: {min_storm_speed} m/s, {max_storm_speed} m/s',
+            f'min. central pressure: {min_central_pressure} hPa',
+            f'max. wind speed: {max_wind_speed} kts',
+            f'Starting at: {start_loc} and ended at: {end_loc}',
+            f'Total track length: {track_length:.2f} km',
+            f'Total track duration: {duration:.2f} days',
+        ]
+        summary = '\n'.join(f)
+        if output is not None:
+            if not isinstance(output, pathlib.Path):
+                path = pathlib.Path(output)
+            if path.exists() and overwrite is False:
+                raise Exception('File exist, set overwrite=True to allow overwrite.')
+            with open(path, 'w+') as fh:
+                fh.write(summary)
+        return summary
+
     def __str__(self):
         record_number = self._generate_record_numbers()
         fort22 = []
@@ -280,6 +326,16 @@ class BestTrackForcing(WindForcing):
 
             self.__atcf = io.BytesIO(response.read())
 
+    @property
+    def track_length(self) -> float:
+        if not hasattr(self, '_track_length'):
+            lons, lats = self.df['longitude'], self.df['latitude']
+            prev = np.asarray([lons.iloc[:-1], lats.iloc[:-1]]).T
+            curr = np.asarray([lons.iloc[1:], lats.iloc[1:]]).T
+            distances = _dist(prev, curr)
+            self._track_length = np.sum(distances)
+        return self._track_length
+
     @property
     def start_date(self) -> datetime:
         return self._start_date
@@ -336,6 +392,11 @@ class BestTrackForcing(WindForcing):
         assert end_date > self.start_date, msg
         self.__end_date = end_date
 
+    @property
+    def duration(self) -> float:
+        d = (self.__end_date - self.__start_date).days
+        return d
+
     @property
     def name(self) -> str:
         return self.df['name'].value_counts()[:].index.tolist()[0]
@@ -356,6 +417,10 @@ class BestTrackForcing(WindForcing):
     def datetime(self):
         return self.df['datetime']
 
+    @property
+    def central_pressure(self):
+        return self.df['central_pressure']
+
     @property
     def speed(self):
         return self.df['speed']
@@ -515,7 +580,7 @@ class BestTrackForcing(WindForcing):
         if _found_start_date is False:
             raise Exception(f'No data within mesh bounding box for storm {self.storm_id}.')
 
-    def plot_track(self, axes=None, show=False, color='k', **kwargs):
+    def plot_track(self, axes=None, show=False, color='k', annotate=True, **kwargs):
         kwargs.update({'color': color})
         if axes is None:
             fig = plt.figure()
@@ -525,11 +590,12 @@ class BestTrackForcing(WindForcing):
             U = self.speed.iloc[i] * np.sin(np.deg2rad(self.direction.iloc[i]))
             V = self.speed.iloc[i] * np.cos(np.deg2rad(self.direction.iloc[i]))
             axes.quiver(self.longitude.iloc[i], self.latitude.iloc[i], U, V, **kwargs)
-            if i % 6 == 0:
-                axes.annotate(
-                    self.df['datetime'].iloc[i],
-                    (self.longitude.iloc[i], self.latitude.iloc[i]),
-                )
+            if annotate:
+                if i % 6 == 0:
+                    axes.annotate(
+                        self.df['datetime'].iloc[i],
+                        (self.longitude.iloc[i], self.latitude.iloc[i]),
+                    )
         if show:
             axes.axis('scaled')
         _fetch_and_plot_coastline(axes, show)
@@ -645,6 +711,8 @@ class BestTrackForcing(WindForcing):
 
 def convert_value(value: Any, to_type: type, round_digits: int = None) -> Any:
     if value is not None and value != "":
+        if not isinstance(value, str) and numpy.isinf(value):
+            return value
         if round_digits is not None and issubclass(to_type, (int, float)):
             if isinstance(value, str):
                 value = float(value)
@@ -716,11 +784,8 @@ def atcf_id(storm_id):
 
 
 def read_atcf(track: PathLike) -> DataFrame:
-    try:
-        with open(track) as track_file:
-            track = track_file.readlines()
-    except:
-        track = str(track).splitlines()
+    with open(track) as track_file:
+        track = track_file.readlines()
 
     data = {
         'basin': [],
