@@ -2,6 +2,6 @@ from adcircpy.validation.COOPS.TidalStations import TidalStations
 
 # from adcircpy.outputs.validation.COOPS.HarmonicConstituents import HarmonicConstituents
 __all__ = [
-    "TidalStations",
+    'TidalStations',
     # "HarmonicConstituents"
 ]
